@@ -3,13 +3,13 @@ import os
 from .tools import non_empty_value
 
 
-def api_url() -> str: return os.environ.get('API_URL', 'https://api.hestia.earth')
+def api_url() -> str: return os.getenv('API_URL', 'https://api.hestia.earth')
 
 
-def api_access_token() -> str: return os.environ.get('API_ACCESS_TOKEN')
+def api_access_token() -> str: return os.getenv('API_ACCESS_TOKEN')
 
 
-def web_url() -> str: return os.environ.get('WEB_URL', 'https://www.hestia.earth')
+def web_url() -> str: return os.getenv('WEB_URL', 'https://www.hestia.earth')
 
 
 def join_args(values) -> str: return '&'.join(list(filter(non_empty_value, values))).strip()
